MetaApi

Struct MetaApi 

pub struct MetaApi { /* private fields */ }
API metadata

Implementations

Source

impl MetaApi

pub async fn get_apple_app_site_association( &self, ) -> Result<GetAppleAppSiteAssociationResponse>

Apple App Site Association — Universal Links manifest

Apple iOS fetches this to verify that the app on the user’s device is allowed to claim Universal Links on this domain. Served as application/json, also at /apple-app-site-association for legacy iOS. Configured via APPLE_TEAM_ID + APPLE_BUNDLE_ID (+ optional APPLE_EXTRA_BUNDLE_IDS comma-list for TestFlight/dev).

GET /.well-known/apple-app-site-association

pub async fn get_client_config(&self) -> Result<GetClientConfigResponse>

Client-side config

GET /api/v1/client-config

pub async fn get_open_api_spec(&self) -> Result<Map<String, Value>>

Get OpenAPI spec

GET /api/v1/openapi.json

pub async fn get_public_landing_stats(&self) -> Result<LandingStats>

Get public landing page statistics

GET /api/v1/public/landing-stats

pub async fn search(&self, params: &SearchParams) -> Result<Value>

Search across agents, sessions, runs

GET /api/v1/search

Required scopes: search:read.